Compendium of overhangs
=======================

The Edinburgh Genome Foundry's compendium of overhangs.
This Python package generates a description of an input set of DNA overhangs and outputs a PDF file.
Additionally, it evaluates suitability of an input set of overhangs for Golden Gate DNA assembly.



**Install:**

.. code:: bash

    pip install overhang


**Web documentation:** `<https://edinburgh-genome-foundry.github.io/Overhang/>`_


**Github page:** `<https://github.com/Edinburgh-Genome-Foundry/Overhang>`_


**License:** MIT

Copyright 2021 Edinburgh Genome Foundry, University of Edinburgh


More biology software
---------------------

.. image:: https://raw.githubusercontent.com/Edinburgh-Genome-Foundry/Edinburgh-Genome-Foundry.github.io/master/static/imgs/logos/egf-codon-horizontal.png
  :target: https://edinburgh-genome-foundry.github.io/

Overhang is part of the `EGF Codons <https://edinburgh-genome-foundry.github.io/>`_ synthetic biology software suite for DNA design, manufacturing and validation.
